"use client"

import Link from "next/link"
import { useAuth } from "@/context/auth-context"
import { LogOut, Menu, X, User, BarChart2 } from "lucide-react"
import { useState } from "react"
import { usePathname } from "next/navigation"

export default function NavBar() {
  const { user, logout } = useAuth()
  const [isMenuOpen, setIsMenuOpen] = useState(false)
  const pathname = usePathname()

  if (!user) return null

  return (
    <nav className="bg-white shadow-sm">
      <div className="container mx-auto px-4">
        <div className="flex justify-between items-center h-16">
          <div className="flex items-center">
            <Link href="/" className="text-xl font-bold text-route-blue">
              Code de la Route
            </Link>
          </div>

          {/* Navigation desktop */}
          <div className="hidden md:flex items-center space-x-4">
            <Link
              href="/"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/" ? "text-blue-600" : ""}`}
            >
              Accueil
            </Link>
            <Link
              href="/lessons"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/lessons" ? "text-blue-600" : ""}`}
            >
              Leçons
            </Link>
            <Link
              href="/exercises"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/exercises" ? "text-blue-600" : ""}`}
            >
              Exercices
            </Link>
            <Link
              href="/simulations"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/simulations" ? "text-blue-600" : ""}`}
            >
              Simulations
            </Link>
            <Link
              href="/exams"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/exams" ? "text-blue-600" : ""}`}
            >
              Examens
            </Link>
            <Link
              href="/profile"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/profile" ? "text-blue-600" : ""}`}
            >
              Mon Profil
            </Link>
            {user.role === "admin" && (
              <Link
                href="/dashboard"
                className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/dashboard" ? "text-blue-600" : ""}`}
              >
                Tableau de Bord
              </Link>
            )}
          </div>

          <div className="hidden md:flex items-center space-x-2">
            <div className="text-sm text-gray-600">
              <span className="font-medium">{user.name}</span> ({user.role})
            </div>
            <button
              onClick={logout}
              className="flex items-center text-gray-600 hover:text-route-red px-3 py-2 rounded-md"
            >
              <LogOut className="h-4 w-4 mr-1" />
              Déconnexion
            </button>
          </div>

          {/* Bouton menu mobile */}
          <div className="md:hidden flex items-center">
            <button
              onClick={() => setIsMenuOpen(!isMenuOpen)}
              className="text-gray-600 hover:text-route-blue focus:outline-none"
            >
              {isMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
            </button>
          </div>
        </div>
      </div>

      {/* Menu mobile */}
      {isMenuOpen && (
        <div className="md:hidden bg-white pt-2 pb-4 px-4">
          <div className="flex flex-col space-y-2">
            <Link
              href="/"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/" ? "text-blue-600" : ""}`}
              onClick={() => setIsMenuOpen(false)}
            >
              Accueil
            </Link>
            <Link
              href="/lessons"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/lessons" ? "text-blue-600" : ""}`}
              onClick={() => setIsMenuOpen(false)}
            >
              Leçons
            </Link>
            <Link
              href="/exercises"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/exercises" ? "text-blue-600" : ""}`}
              onClick={() => setIsMenuOpen(false)}
            >
              Exercices
            </Link>
            <Link
              href="/simulations"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/simulations" ? "text-blue-600" : ""}`}
              onClick={() => setIsMenuOpen(false)}
            >
              Simulations
            </Link>
            <Link
              href="/exams"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md ${pathname === "/exams" ? "text-blue-600" : ""}`}
              onClick={() => setIsMenuOpen(false)}
            >
              Examens
            </Link>
            <Link
              href="/profile"
              className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md flex items-center ${pathname === "/profile" ? "text-blue-600" : ""}`}
              onClick={() => setIsMenuOpen(false)}
            >
              <User className="h-4 w-4 mr-2" />
              Mon Profil
            </Link>
            {user.role === "admin" && (
              <Link
                href="/dashboard"
                className={`text-gray-600 hover:text-route-blue px-3 py-2 rounded-md flex items-center ${pathname === "/dashboard" ? "text-blue-600" : ""}`}
                onClick={() => setIsMenuOpen(false)}
              >
                <BarChart2 className="h-4 w-4 mr-2" />
                Tableau de Bord
              </Link>
            )}
            <div className="border-t border-gray-200 my-2 pt-2">
              <div className="text-sm text-gray-600 px-3 py-1">
                <span className="font-medium">{user.name}</span> ({user.role})
              </div>
              <button
                onClick={() => {
                  logout()
                  setIsMenuOpen(false)
                }}
                className="flex items-center w-full text-left text-gray-600 hover:text-route-red px-3 py-2 rounded-md"
              >
                <LogOut className="h-4 w-4 mr-2" />
                Déconnexion
              </button>
            </div>
          </div>
        </div>
      )}
    </nav>
  )
}
